@@ -244,6 +244,12 @@ Plugin.create(:twitter) do
     280 - tweet[:weighted_length]
   end
 
+  defspell(:around_message, :twitter_tweet) do |message|
+    Thread.new do
+      message.around(true)
+    end
+  end
+
   def trim_hidden_regions(text)
     trim_hidden_header(trim_hidden_footer(text))
   end
@@ -289,13 +295,8 @@ Plugin.create(:twitter) do
           source.retweeted_sources.delete(message) end end } end
 
   onappear do |messages|
-    retweets = messages.select(&:retweet?).map do |message|
-      result = message.retweet_ancestors.to_a[-2]
-      fail "invalid retweet #{message.inspect}. ancestors: #{message.retweet_ancestors.to_a.inspect}" unless result.is_a?(Plugin::Twitter::Message)
-      result
-    end
-    if not retweets.empty?
-      Plugin.call(:retweet, retweets)
+    messages.select(&:retweet?).each do |message|
+      Plugin.call(:share, message.user, message.retweet_ancestor)
     end
   end
 
