@@ -127,7 +127,7 @@ class UserConfig
                                   'delete_favorite',
                                   'delete'],
 
-    :subparts_order => ["Gdk::ReplyViewer", "Gdk::SubPartsFavorite", "Gdk::SubPartsRetweet"],
+    :subparts_order => ["Gdk::ReplyViewer", "Gdk::SubPartsFavorite", "Gdk::SubPartsShare"],
 
     :activity_mute_kind => ["error"],
     :activity_show_timeline => ["system", "achievement"],
@@ -154,6 +154,7 @@ class UserConfig
     :world_shifter_visibility => :auto,
 
     :miraclepainter_expand_custom_emoji => true,
+    :ui_scale => :auto
   }
 
   @@watcher = Hash.new{ [] }
